package com.ruoyi.interfaces.service;

import com.ruoyi.interfaces.domain.TbModels;

import java.util.List;

/**
 * 模型Service接口
 * 
 * @author ruoyi
 * @date 2025-06-12
 */
public interface TbModelsService
{
    /**
     * 查询模型
     * 
     * @param modelId 模型主键
     * @return 模型
     */
    public TbModels selectTbModelsByModelId(Long modelId);

    /**
     * 查询模型列表
     * 
     * @param tbModels 模型
     * @return 模型集合
     */
    public List<TbModels> selectTbModelsList(TbModels tbModels);

    /**
     * 新增模型
     * 
     * @param tbModels 模型
     * @return 结果
     */
    public int insertTbModels(TbModels tbModels);

    /**
     * 修改模型
     * 
     * @param tbModels 模型
     * @return 结果
     */
    public int updateTbModels(TbModels tbModels);

    /**
     * 批量删除模型
     * 
     * @param modelIds 需要删除的模型主键集合
     * @return 结果
     */
    public int deleteTbModelsByModelIds(Long[] modelIds);

    /**
     * 删除模型信息
     * 
     * @param modelId 模型主键
     * @return 结果
     */
    public int deleteTbModelsByModelId(Long modelId);
}